@@ -346,6 +346,7 @@ except ModulenotfoundExp_ as exp:
                 self, input_data, node=None, input_name=''):
             values = input_data.split()
             for value in values:
+                value = self.gds_parse_boolean(value, node, input_name)
                 if value not in (True, 1, False, 0, ):
                     raise_parse_error(
                         node,
@@ -1404,16 +1405,19 @@ class tGeoData(GeneratedsSuper):
         value = find_attr_value_('doubleListData', node)
         if value is not None and 'doubleListData' not in already_processed:
             already_processed.add('doubleListData')
+            self.gds_validate_double_list(value, node, 'doubleListData')
             self.doubleListData = value
             self.validate_tDoubleListRestriction(self.doubleListData.split())    # validate type tDoubleListRestriction
         value = find_attr_value_('integerListData', node)
         if value is not None and 'integerListData' not in already_processed:
             already_processed.add('integerListData')
+            self.gds_validate_integer_list(value, node, 'integerListData')
             self.integerListData = value
             self.validate_tIntegerListRestriction(self.integerListData.split())    # validate type tIntegerListRestriction
         value = find_attr_value_('floatListData', node)
         if value is not None and 'floatListData' not in already_processed:
             already_processed.add('floatListData')
+            self.gds_validate_float_list(value, node, 'floatListData')
             self.floatListData = value
             self.validate_tFloatListRestriction(self.floatListData.split())    # validate type tFloatListRestriction
         value = find_attr_value_('dateTimeListData', node)
@@ -1434,6 +1438,7 @@ class tGeoData(GeneratedsSuper):
         value = find_attr_value_('booleanListData', node)
         if value is not None and 'booleanListData' not in already_processed:
             already_processed.add('booleanListData')
+            self.gds_validate_boolean_list(value, node, 'booleanListData')
             self.booleanListData = value
             self.validate_tBooleanListRestriction(self.booleanListData.split())    # validate type tBooleanListRestriction
     def buildChildren(self, child_, node, nodeName_, fromsubclass_=False, gds_collector_=None):
